# -*- coding: utf-8 -*-
import q5


class App(q5.BaseApp):
    def setup(self):
        q5.title('q5 app')

    def update(self):
        pass

    def draw(self):
        q5.background(220)
        q5.ellipse(0.0, 0.0, 200.0, 200.0)

    def mouse_pressed(self):
        pass

    def mouse_released(self):
        pass

    def mouse_moved(self):
        pass

    def mouse_entered(self):
        pass

    def mouse_exited(self):
        pass

    def key_pressed(self):
        pass

    def key_released(self):
        pass


if __name__ == '__main__':
    app = App()
    app.run()



from .engine import *  #noqa F403
from .draw import *  #noqa F403
from .app import BaseApp, Vector

try:
    from ._version import version
    __version__ = version
except ImportError:
    pass

__author__ = 'eqs'
__all__ = [BaseApp, Vector]



import math
import q5


class App(q5.BaseApp):
    def setup(self):
        self.x = 0.0
        self.y = 0.0

    def update(self):
        t = q5.frame_count
        u = t / 60.0 * 2 * math.pi
        self.x = 100.0 * math.cos(u)
        self.y = 100.0 * math.sin(u)

    def draw(self):
        q5.background(220)
        q5.translate(self.x, self.y)
        q5.ellipse(0.0, 0.0, 100.0, 100.0)


if __name__ == '__main__':
    app = App()
    app.run()



import math
import random
from typing import Tuple
from dataclasses import dataclass
import q5

N_STARS = 64
colors = [
    (224, 221, 0), (112, 22, 224), (224, 72, 11), (22, 224, 192)
]


class Star:

    N: int
    radius: float
    pos: q5.Vector
    vel: q5.Vector
    angle_vel: float
    color: Tuple

    def __init__(self, pos: q5.Vector, vel: q5.Vector,
                 radius: float = 32.0, angle_vel: float = 0.25,
                 color: Tuple = (220, 220, 0)):
        self.N = 5
        self.radius = radius
        self.pos = pos
        self.vel = vel
        self.angle_vel = angle_vel
        self.color = color

    def update(self):
        if self.pos.x < -q5.width / 2.0 - self.radius:
            self.pos.x = self.pos.x + q5.width + self.radius * 2.0
        if self.pos.x > q5.width / 2.0 + self.radius:
            self.pos.x = self.pos.x - q5.width - self.radius * 2.0
        if self.pos.y < -q5.height / 2.0 - self.radius:
            self.pos.y = self.pos.y + q5.height + self.radius * 2.0
        if self.pos.y > q5.height / 2.0 + self.radius:
            self.pos.y = self.pos.y - q5.height - self.radius * 2.0

        self.pos = self.pos + self.vel

    def draw(self):
        t = q5.frame_count
        u = t / 60.0 * 2 * math.pi * self.angle_vel

        pts = []
        for n in range(self.N * 2):
            p = n * math.pi / self.N
            s = self.radius if n % 2 == 0 else self.radius / 2.0
            x = s * math.cos(u + p)
            y = s * math.sin(u + p)
            pts.append((x, y))

        q5.no_fill()
        q5.stroke(*self.color)
        q5.stroke_weight(2.0)

        q5.push_matrix()
        q5.translate(self.pos.x, self.pos.y)
        q5.polygon(pts)
        q5.pop_matrix()


def generate_star(x=0.0, y=0.0):
    mag = random.uniform(1.0, 6.0)
    angle = random.uniform(0.0, math.pi * 2.0)
    radius = random.uniform(16.0, 48.0)
    angle_vel = random.uniform(0.15, 0.75)
    if random.random() > 0.5:
        angle_vel = -angle_vel

    star = Star(
        q5.Vector(x, y),
        q5.Vector.from_angle(angle, mag=mag),
        radius=radius,
        angle_vel=angle_vel,
        color=random.choice(colors)
    )

    return star


class App(q5.BaseApp):
    def setup(self):
        self.stars = []
        for k in range(N_STARS):
            star = generate_star()
            self.stars.append(star)

    def update(self):
        for star in self.stars:
            star.update()

    def draw(self):
        q5.background(0, 0, 0)
        for star in self.stars:
            star.draw()

    def mouse_pressed(self):
        if q5.mouse_button == q5.MOUSE_LEFT:
            star = generate_star(q5.mouse_x, q5.mouse_y)
            self.stars.append(star)


if __name__ == '__main__':
    app = App()
    app.run()



# -*- coding: utf-8 -*-
import q5


class App(q5.BaseApp):
    def setup(self):
        q5.title('q5 app')

    def update(self):
        pass

    def draw(self):
        q5.background(220)
        q5.ellipse(0.0, 0.0, 200.0, 200.0)


if __name__ == '__main__':
    app = App()
    app.run()



# -*- coding: utf-8 -*-
import q5
import math

N = 8


def draw_face():
    q5.rect(0, 0, 200, 150)
    q5.circle(-50, 25, 25)
    q5.circle(50, 25, 25)
    q5.rect(0, -25, 100, 25)


class App(q5.BaseApp):
    def setup(self):
        q5.title('q5 app')

    def update(self):
        pass

    def draw(self):
        q5.background(220)

        q5.stroke_weight(1.0)
        draw_face()

        q5.stroke_weight(2.0)
        for k in range(N):
            t = q5.frame_count / 300.0 * 2.0 * math.pi
            phi = k / N * 2.0 * math.pi

            q5.push_matrix()

            q5.rotate(t + phi)
            q5.translate(200.0, 0.0)
            q5.scale(0.5, 0.5)

            q5.push_matrix()
            q5.rotate(-math.pi / 2.0)
            draw_face()
            q5.pop_matrix()

            q5.pop_matrix()


if __name__ == '__main__':
    app = App()
    app.run()



import math
import q5


class App(q5.BaseApp):
    def __init__(self):
        self.N = 5
        self.pts = []

    def update(self):
        t = q5.frame_count
        u = t / 60.0 * 2 * math.pi * 0.25

        self.pts = []
        for n in range(self.N * 2):
            p = n * math.pi / self.N
            r = 200.0 if n % 2 == 0 else 100.0
            x = r * math.cos(u + p)
            y = r * math.sin(u + p)
            self.pts.append((x, y))

    def draw(self):
        q5.background(0)
        q5.no_fill()
        q5.stroke(220, 220, 0)
        q5.stroke_weight(5.0)
        q5.polygon(self.pts)


if __name__ == '__main__':
    app = App()
    app.run()



import numpy as np
from .engine import (
    polygon_list, polygon_ndarray, polyline_list, polyline_ndarray
)

__all__ = ["polygon", "polyline"]


def polygon(pts):
    if isinstance(pts, np.ndarray):
        polygon_ndarray(pts)
    elif isinstance(pts, list):
        polygon_list(pts)
    else:
        raise TypeError('Invalid type is detected: {}'.format(type(pts)))


def polyline(pts):
    if isinstance(pts, np.ndarray):
        polyline_ndarray(pts)
    elif isinstance(pts, list):
        polyline_list(pts)
    else:
        raise TypeError('Invalid type is detected: {}'.format(type(pts)))



import math
import q5

import numpy as np


class App(q5.BaseApp):
    def __init__(self):
        self.N = 200
        self.pts = []

    def update(self):
        t = q5.frame_count
        u = t / 60.0 * 2 * math.pi

        self.pts = []
        x = np.linspace(-np.pi, np.pi, self.N)
        y = 100.0 * np.sin(x + u)
        x = x / (2*np.pi) * 300.0

        self.pts = np.vstack([x, y]).T.tolist()
        self.pts = list(map(tuple, self.pts))

    def draw(self):
        q5.background(0)
        q5.fill(255, 0, 0)
        q5.stroke(220)
        q5.stroke_weight(2.0)
        q5.polyline(self.pts)


if __name__ == '__main__':
    app = App()
    app.run()



# -*- coding: utf-8 -*-
from setuptools import setup, find_packages
from setuptools_rust import Binding, RustExtension


setup(
    name='q5',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    packages=find_packages(),
    zip_safe=False,
    include_package_data=True,
    rust_extensions=[
        RustExtension(
            'q5.engine',
            path='Cargo.toml',
            binding=Binding.PyO3,
            debug=False,
        )
    ],
    license='MIT',
    python_requires='>=3.8',
    install_requires=[
        'numpy>=1.20'
    ],
    classifiers=[
        'Intended Audience :: Education',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Topic :: Multimedia :: Graphics',
        'Topic :: Multimedia :: Sound/Audio'
    ]
)
